# Meta-Learning with Implicit Gradients

In this example, we re-implemented
[Meta-Learning with Implicit Gradients](https://arxiv.org/abs/1909.04630)

### Script
You can run the iMAML experiment with the following script:

```bash
python main.py --inner_steps 5
```

### Warning
Our implementation currently doesn't match the accuracy of the original paper.
We are actively investigating the issue, and update the repo as soon as possible.
